#!/bin/bash

. ./_local_prepare_config.sh

prep_dir=essentia-audio-features


stages_to_run="scrape_contestants|download_audio|compute_audio_features|retrieve_musicbrainzid"

if [ $# -ge 1 ] ; then
    stages_to_run=$1; shift
fi

run_scrape=`echo $stages_to_run   | grep scrape_contestants     | wc -l`
run_download=`echo $stages_to_run | grep download_audio         | wc -l`
run_compute=`echo $stages_to_run  | grep compute_audio_features | wc -l`
run_acousticid=`echo $stages_to_run  | grep retrieve_musicbrainzid | wc -l`

echo ""
echo "Running with stages:"
echo "  scrape_contents        : $run_scrape"
echo "  download_audio         : $run_download"
echo "  compute_audio_features : $run_compute"
echo "  retrieve_musicbrainzid : $run_acousticid"

echo ""
echo "Sleeping for 5 seconds, to give time to press ^C to stop ..."
sleep 5
echo  "... continuing"
echo ""

if [ "x$PYTHON3_HOME" = "x" ] && [ ! -d "./$my_python" ] ; then
    echo "" 1>&2
    echo "Failed to find: ./$my_python" 1>&2
    echo "Have you run:" 1>&2
    echo "  ./CREATE-VENV-PYTHON3.sh $my_python" 1>&2
    echo "" 1>&2
    
    exit 1
fi

if [ "x$PYTHON3_HOME" = "x" ] ; then
    source  ./$my_python/bin/activate
fi

echo ""

if [ ! -d "$prep_dir" ] ; then
    echo "Checking out through 'git':"
    # echo "  https://github.com/Spijkervet/eurovision-dataset.git              => $prep_dir"
    echo "  https://github.com/davidbwaikato/eurovision-dataset $prep_dir"
    
    echo ""
    #git clone https://github.com/Spijkervet/eurovision-dataset.git $prep_dir
    git clone https://github.com/davidbwaikato/eurovision-dataset $prep_dir

    # export CRYPTOGRAPHY_DONT_BUILD_RUST=1
    # pip install --upgrade pip

    echo "Running pip3 install -r requirements.txt"
    cd "$prep_dir" && pip3 install -r requirements.txt && cd ..

    if [ $? != 0 ] ; then
	echo "!!!!" 1>&2
	echo "! Error enountered running git clone followed by pip3 install -r requirements.txt" 1>&2
	echo "!!!!" 1>&2

	if [ "x$PYTHON3_HOME" = "x" ] ; then    	
	    deactivate
	fi
	exit 1
    fi
	
else
    echo "Detected existing $prep_dir"
fi


if [ ! -f $prep_dir/geckodriver-v0.30.0-linux64.tar.gz ] ; then
   echo "Downloading:"
   echo "   https://github.com/mozilla/geckodriver/releases/download/v0.30.0/geckodriver-v0.30.0-linux64.tar.gz"

   echo ""
   wget --no-check-certificate \
	-O $prep_dir/geckodriver-v0.30.0-linux64.tar.gz \
	https://github.com/mozilla/geckodriver/releases/download/v0.30.0/geckodriver-v0.30.0-linux64.tar.gz
else
    echo "Detected $prep_dir/geckodriver-v0.30.0-linux64.tar.gz. => No need to download"
fi

if [ ! -f $prep_dir/geckodriver ] ; then

    echo "Untarring:"
    echo "  $prep_di8r/geckodriver-v0.30.0-linux64.tar.gz => geckodriver (binary executable) "
    cd $prep_dir && tar xvzf geckodriver-v0.30.0-linux64.tar.gz && cd ..
else
    echo "Detected $prep_dir/geckodriver                         => No need to untar"
fi


# Get geckodriver on PATH
export PATH=$PWD/$prep_dir:$PATH
       
run_scrape_status=0
if [ $run_scrape = "1" ] ; then
    if [ $# = 0 ] ; then
	cd "$prep_dir" \
	    && /bin/rm -f "votes-1956.csv" \
	    && /bin/rm -f "contestants-1956.csv" \
	    && python3 -u ./main.py --start 1956 --end 1956 \
		       \
	    && /bin/rm -f "votes-1957-${esc_cutoff_endyear}.csv" \
	    && /bin/rm -f "contestants-1957-${esc_cutoff_endyear}.csv" \
	    && python3 -u ./main.py --start 1957 --end $esc_cutoff_endyear
	run_scrape_status=$?
	cd ..
    else
	cd "$prep_dir" \
	    && python3 -u ./main.py $*
	run_scrape_status=$?
	cd ..
    fi
fi

run_download_status=0
if [ $run_scrape_status = 0 ] && [ $run_download = "1" ] ; then
    if [ $# = 0 ] ; then
	# append CSV fileanme to $*
	set -- "$@" "contestants-1956.csv" "contestants-1957-${esc_cutoff_endyear}.csv"
    fi

    echo '****'  python3 -u ./audio.py $*
    cd "$prep_dir" \
	&& python3 -u ./audio.py $*
    run_download_status=$?
    cd ..
fi

run_compute_status=0
if [ $run_download_status = 0 ] && [ $run_compute = "1" ] ; then
    cd "$prep_dir" \
	&& python3 -u ./audio_features.py $*
    run_download_status=$?
    cd ..
fi

if [ $run_compute_status = 0 ] && [ $run_acousticid = "1" ] ; then
    cd "$prep_dir" \
	&& python3 -u ./acousticbrainz_id.py $*
    run_retrieve_status=$?
    cd ..
fi

echo ""
echo "**************************************"
echo "* Done Generate Essentia Features Data"
echo "**************************************"

if [ "x$PYTHON3_HOME" = "x" ] ; then    	
    deactivate
fi
